trainer.MessageManager
======================

.. currentmodule:: trainer

.. autoclass:: MessageManager

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~MessageManager.__init__
      ~MessageManager.band_trainName
      ~MessageManager.clear_trainName
      ~MessageManager.delete_queue
      ~MessageManager.describe
      ~MessageManager.free_trainName
      ~MessageManager.list_queues
      ~MessageManager.pull
      ~MessageManager.pull_deplete
      ~MessageManager.push
      ~MessageManager.show_all_topic
   
   

   
   
   